#!/usr/bin/env python
# -*- coding: utf-8 -*-

# #########################################################################
# Copyright (c) 2016, UChicago Argonne, LLC. All rights reserved.         #
#                                                                         #
# Copyright 2016. UChicago Argonne, LLC. This software was produced       #
# under U.S. Government contract DE-AC02-06CH11357 for Argonne National   #
# Laboratory (ANL), which is operated by UChicago Argonne, LLC for the    #
# U.S. Department of Energy. The U.S. Government has rights to use,       #
# reproduce, and distribute this software.  NEITHER THE GOVERNMENT NOR    #
# UChicago Argonne, LLC MAKES ANY WARRANTY, EXPRESS OR IMPLIED, OR        #
# ASSUMES ANY LIABILITY FOR THE USE OF THIS SOFTWARE.  If software is     #
# modified to produce derivative works, such modified software should     #
# be clearly marked, so as not to confuse it with the version available   #
# from ANL.                                                               #
#                                                                         #
# Additionally, redistribution and use in source and binary forms, with   #
# or without modification, are permitted provided that the following      #
# conditions are met:                                                     #
#                                                                         #
#     * Redistributions of source code must retain the above copyright    #
#       notice, this list of conditions and the following disclaimer.     #
#                                                                         #
#     * Redistributions in binary form must reproduce the above copyright #
#       notice, this list of conditions and the following disclaimer in   #
#       the documentation and/or other materials provided with the        #
#       distribution.                                                     #
#                                                                         #
#     * Neither the name of UChicago Argonne, LLC, Argonne National       #
#       Laboratory, ANL, the U.S. Government, nor the names of its        #
#       contributors may be used to endorse or promote products derived   #
#       from this software without specific prior written permission.     #
#                                                                         #
# THIS SOFTWARE IS PROVIDED BY UChicago Argonne, LLC AND CONTRIBUTORS     #
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       #
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS       #
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL UChicago     #
# Argonne, LLC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,        #
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,    #
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;        #
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER        #
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT      #
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN       #
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE         #
# POSSIBILITY OF SUCH DAMAGE.                                             #
# #########################################################################
"""Constants in cgs units.

Attributes
----------
AVOGADRO_NUMBER : float
    Avagadro constant [1/mol]
BOLTZMANN_CONSTANT : float
    Boltzmann constant [erg/k]
CLASSICAL_ELECTRON_RADIUS : float
    Classical electron radius [cm]
ELECTRONIC_CHARGE : float
    Electronic charge [esu]
ELECTRON_VOLT : float
    Electron volt (keV) [erg]
ELECTRON_MASS : float
    Electron mass [g]
FINE_STRUCTURE_CONSTANT : float
    Fine structure constant
PLANCK_CONSTANT : float
    Reduced planck's constant [keV*s]
PROTON_MASS : float
    Proton mass [g]
SPEED_OF_LIGHT : float
    Speed of light in vacuum [cm/s]
THOMPSON_CROSS_SECTION : float
    Thomson cross section [cm^2]
PI : float
    Ratio of a circle's circumference to its diameter
"""

AVOGADRO_NUMBER = 6.02214129e+23
BOLTZMANN_CONSTANT = 1.3806488e-16
CLASSICAL_ELECTRON_RADIUS = 2.8179402894e-13
ELECTRONIC_CHARGE = 4.80320425e-10
ELECTRON_VOLT = 1.602176565e-9
ELECTRON_MASS = 9.10938188e-28
FINE_STRUCTURE_CONSTANT = 7.2973525698e-3
PLANCK_CONSTANT = 6.58211928e-19
PROTON_MASS = 1.67261777e-24
SPEED_OF_LIGHT = 299792458e+2
THOMPSON_CROSS_SECTION = 6.652458734e-25
PI = 3.14159265359

RADIUS = 10

DEFAULT_ENERGY = 15.0


def wavelength(energy):
    """Return wavelength [cm] of light given energy [keV]."""
    return 2 * PI * PLANCK_CONSTANT * SPEED_OF_LIGHT / energy
